==> grumpy_checks-0.1.4.tar.gz: grumpy_checks-0.1.4/grumpy_checks/cli/cat.py <==
import random

cat = """
░──▓██████▓██▒─▓▓▓▓▓▒▒▓▓▒▒░▒█▒▒█▓▓▒▒░░▒▒▒███
█░─███████▓▓█▒─▓▓▓▓▓▒▒▓▓░▒▓░▓▒▒██▓▒▒▒▒▒▒████
▒░▒████▓███▓█▒─▓▒▒▓▓▒▒▓▓░▒▓─▓▓▒██▓▒▓▒▒▒█████
▒▒▓█████▓███▓▒░▓▒▒▓█▒░▓▓░▒▓─▓█▒██▓▒▒▒░██████
▒▓██████▓████▓▓▓▒▓▓▓▒░▓▓──▓░▓▓▒██▓▒░░▓██████
▓█████▓█▓▓████▓▓▒▓▓▓▒─█▓──▓░██░▓█▓▒─▒███████
▓████▓▓▓▓▓████▓▓▒▒▓▓▒─▓▓─▓▓─▓█▒██▓░▒███████▓
██████▓█▓▓█████▓▓─▒▓▒─▓▒─▓▓─▒▓░██▒▒████████▓
█████████▓▓█████▓▒▒▒▓─▒▒─░▓─▓▓░██▒▓████████▓
▓▓███████▓▓███▓██▓▓▓▓─▒▒──▓░▓▓░██▓█████████▓
▓█████████▓▓██▓██▓▒▓█▓██▒─▓▒▓▓░▓████████▓██▓
▓█████████▓▓█████▓█████████░░▓▒▓███████▓▒██▓
▒████████████████▓▓──────▒█▓██▓█████████▓▒██
▓██▓██▓████████▓░──────────▒▓▒▓██████▓▓▓▓▓██
▓██▓███▓█████▓▒────────────░▒▓██████▓▓▒▓▓▓▓█
████████▓█▓▒▒░───░───────────▒▓▓█████▓▓▒▓▒▓█
████████▓▒▒▒░──░▒▓▓░░──░────░░▒▒▓████▓▓▒▓▓██
████████▒▒▒▒▒░░▓▓▓▓▒░─░░░░░░░░▒▒▒▒███▓▓▓▒███
████████▒▒▒▓▒▒▒▓█▒▒▒▒▒▓▒▒▒▒▒░░░░░▒▓████▓▓▓██
████████▓▓▓▓▓▓▓██▒▒▓▓▓█▓▒▓▒▒░░░░░░▒▒▓███████
████████▓▓█▓▓███▓▒▒█▓▒██▒▓▒▒▒░░░░░░▒▒▓██████
███████▓▓▓█▓████▓▒▒█▓▓██▓▓▓▒▒░▒░░░░▒▒▓████▓█
███████▓▓█▓████▓▓▒▒█▓▓███▓▓▒▒▒░░░░░░▒▒▓█████
█████▓█████████▓█▓▒████████▓▓▒░──░░░░▒▓████▓
█████▓█████████▓▓▓▒████████▓▓▓▒░░░░░▒▒▓█████
████▓▓█████████▒▓▒▓███████▓▓▓▓▓▓░─▒░▒▒██████
████▓▓█████████▒▒▒▒███████████▓▓▓▒░░▒▒▓█████
████▓██████████▒▒▒▒██████████████▒─░░░▒█████
████▓██████████▓▒░▒████████▓▒░███▓─────▓████
████▓███▓██▓███▓──▒████████▓▒▒█▓██▓░────▓███
████▓███▓██▓███▒──░█████████▒▓█████▓░░───▓██
███▓▓█████████▓────▓████▓▓█▓▓███████▒░░░─░▓█
███▓██████████▒────▓█████▓▓▓████████▓▒░░──░▓
███▓█████████──────░█████▓█████████▓▓▓▒░░░░▓
██▓▓████████▓▒▒░────██████████████▓▒▒▓▒░▒▒░▒
███▓████████▓▓▓▓▒───░█████████████▓▒▒▒▒▒░░░░
█▓▓████████▓▓█▓██────▒███████████▓▓▒▒▒▓▒░░──
██▓▓██████▓▒▒▓█▓▒─────▓██▓█████▓▓▓▓▒▒░▒▒░░░─
██▓▓▓████▓▒▒░░▓▓░──────▓██▓█▓▓▓▓▓█▓▒▒░░▒░░──
███▓████▓▒▒▒▒▒██▓░──────▓██▓▓▒▓▓▓▓▒▒▒░░▒▒░──
██▓▓▓███▓▒▒▒▓▓▓▓█▓░──────▒▓▓█▓▒▓█▓▒▒░░░▒░───
██▓▓▓▓▓▓▒▒▒▓▓▒▒─░▓▓───────▒█▓▓▓▓▒▒▒░░─░▒░───
███▓███▓▒▒▓▓▒▒▒▒──▓▓░░───▒▓▓▒▒▓█▓▒▒▒░──░░───
██▓▒▓▓▓▓▒▒▓▓▒▒▓▒▒░░▓▓▒░──▓▓▓▒▒▒▒▒▓▓▓▒░─░────
███▓▓▓▓▓▒▒▓▓▒▒▓▒▒▒▒▒▓▒▒░─░▓▒─░▓▓▓▒▓▓▓──░────
███▒▓▓▓▓▓▒▓▓▒▒▒▓▒▓▒▒▓▓░░▒▓▓▒▒░▒▒▒▒▒▒▓▒░─────
▓▓█▓▓▓▓██▓▓▓▒▒▒▒▒▒▓▒▓▓▒░▒▒▒▒▒▓▓▒▒▒▒▒░───────
███▓▓▓█▓▓▓▓▓▒▒▒▒▒▒▒▒▓▓▓▒▒▓▒░▒▓██▓▒▓▓░───────
███▒▓▓▓█▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒▓▓▒▓▓█▓▓▒──────────
███▒▓▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒▓▓▓▓▒▒────────────
████▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒░░░──────────
████▒▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒░░░░░░░░▒─░░────────
████▒▒▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒░░░▒▒░░─░░░░────────
████▓▒▓▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒░░▒▒▒░░░─░░─────────
█████▒▒▓▒▒▓▓▓▓▓▒▒▒▒▓▒▒▒▒░░░░▒▒▒▒░░░─────────
████▓▒▓▓▓▓▓▓▓▓▓▓▓▓▒▓▒▒▒▒▒▒░░▒▒▒▒░░░─────────
████▓▒▓▓▓▓▓▓▒▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒░░─░─────────
████▓▓▓▓▓▓▒▒▒▒▓▓▓▓▓▓▒▒▓▒▒▒▒▒▒▒░─░░░─────────
████▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒░░░░░▒░─────────
"""


def random_phrase():
    phrases = [
        "Sometimes you can't tell if you're just in a bad mood\
             or everyone around you is being annoying.",
        "You need a hug for these issues, go hug a cactus.",
        "You have a problem with my attitude? I have an attitude ...\
             you have the problem.",
        "The problem with some people ... is that they exist.",
        "The worst part of my day is hearing you complain about your \
            lint issues."
    ]
    return random.choice(phrases)

==> grumpy_checks-0.1.7.tar.gz: grumpy_checks-0.1.7/grumpy_checks/cli/cat.py <==
"""Cat.

Grumpy cat output strings for feedback on checks.

Objects
=======
    - cat: str, grumpy cat ascii art

Functions
=========
    - random_phrase: generate a random grumpy feedback phrase
        displaying displeasure at a developers incompetence.
"""


import random

cat = """
░──▓██████▓██▒─▓▓▓▓▓▒▒▓▓▒▒░▒█▒▒█▓▓▒▒░░▒▒▒███
█░─███████▓▓█▒─▓▓▓▓▓▒▒▓▓░▒▓░▓▒▒██▓▒▒▒▒▒▒████
▒░▒████▓███▓█▒─▓▒▒▓▓▒▒▓▓░▒▓─▓▓▒██▓▒▓▒▒▒█████
▒▒▓█████▓███▓▒░▓▒▒▓█▒░▓▓░▒▓─▓█▒██▓▒▒▒░██████
▒▓██████▓████▓▓▓▒▓▓▓▒░▓▓──▓░▓▓▒██▓▒░░▓██████
▓█████▓█▓▓████▓▓▒▓▓▓▒─█▓──▓░██░▓█▓▒─▒███████
▓████▓▓▓▓▓████▓▓▒▒▓▓▒─▓▓─▓▓─▓█▒██▓░▒███████▓
██████▓█▓▓█████▓▓─▒▓▒─▓▒─▓▓─▒▓░██▒▒████████▓
█████████▓▓█████▓▒▒▒▓─▒▒─░▓─▓▓░██▒▓████████▓
▓▓███████▓▓███▓██▓▓▓▓─▒▒──▓░▓▓░██▓█████████▓
▓█████████▓▓██▓██▓▒▓█▓██▒─▓▒▓▓░▓████████▓██▓
▓█████████▓▓█████▓█████████░░▓▒▓███████▓▒██▓
▒████████████████▓▓──────▒█▓██▓█████████▓▒██
▓██▓██▓████████▓░──────────▒▓▒▓██████▓▓▓▓▓██
▓██▓███▓█████▓▒────────────░▒▓██████▓▓▒▓▓▓▓█
████████▓█▓▒▒░───░───────────▒▓▓█████▓▓▒▓▒▓█
████████▓▒▒▒░──░▒▓▓░░──░────░░▒▒▓████▓▓▒▓▓██
████████▒▒▒▒▒░░▓▓▓▓▒░─░░░░░░░░▒▒▒▒███▓▓▓▒███
████████▒▒▒▓▒▒▒▓█▒▒▒▒▒▓▒▒▒▒▒░░░░░▒▓████▓▓▓██
████████▓▓▓▓▓▓▓██▒▒▓▓▓█▓▒▓▒▒░░░░░░▒▒▓███████
████████▓▓█▓▓███▓▒▒█▓▒██▒▓▒▒▒░░░░░░▒▒▓██████
███████▓▓▓█▓████▓▒▒█▓▓██▓▓▓▒▒░▒░░░░▒▒▓████▓█
███████▓▓█▓████▓▓▒▒█▓▓███▓▓▒▒▒░░░░░░▒▒▓█████
█████▓█████████▓█▓▒████████▓▓▒░──░░░░▒▓████▓
█████▓█████████▓▓▓▒████████▓▓▓▒░░░░░▒▒▓█████
████▓▓█████████▒▓▒▓███████▓▓▓▓▓▓░─▒░▒▒██████
████▓▓█████████▒▒▒▒███████████▓▓▓▒░░▒▒▓█████
████▓██████████▒▒▒▒██████████████▒─░░░▒█████
████▓██████████▓▒░▒████████▓▒░███▓─────▓████
████▓███▓██▓███▓──▒████████▓▒▒█▓██▓░────▓███
████▓███▓██▓███▒──░█████████▒▓█████▓░░───▓██
███▓▓█████████▓────▓████▓▓█▓▓███████▒░░░─░▓█
███▓██████████▒────▓█████▓▓▓████████▓▒░░──░▓
███▓█████████──────░█████▓█████████▓▓▓▒░░░░▓
██▓▓████████▓▒▒░────██████████████▓▒▒▓▒░▒▒░▒
███▓████████▓▓▓▓▒───░█████████████▓▒▒▒▒▒░░░░
█▓▓████████▓▓█▓██────▒███████████▓▓▒▒▒▓▒░░──
██▓▓██████▓▒▒▓█▓▒─────▓██▓█████▓▓▓▓▒▒░▒▒░░░─
██▓▓▓████▓▒▒░░▓▓░──────▓██▓█▓▓▓▓▓█▓▒▒░░▒░░──
███▓████▓▒▒▒▒▒██▓░──────▓██▓▓▒▓▓▓▓▒▒▒░░▒▒░──
██▓▓▓███▓▒▒▒▓▓▓▓█▓░──────▒▓▓█▓▒▓█▓▒▒░░░▒░───
██▓▓▓▓▓▓▒▒▒▓▓▒▒─░▓▓───────▒█▓▓▓▓▒▒▒░░─░▒░───
███▓███▓▒▒▓▓▒▒▒▒──▓▓░░───▒▓▓▒▒▓█▓▒▒▒░──░░───
██▓▒▓▓▓▓▒▒▓▓▒▒▓▒▒░░▓▓▒░──▓▓▓▒▒▒▒▒▓▓▓▒░─░────
███▓▓▓▓▓▒▒▓▓▒▒▓▒▒▒▒▒▓▒▒░─░▓▒─░▓▓▓▒▓▓▓──░────
███▒▓▓▓▓▓▒▓▓▒▒▒▓▒▓▒▒▓▓░░▒▓▓▒▒░▒▒▒▒▒▒▓▒░─────
▓▓█▓▓▓▓██▓▓▓▒▒▒▒▒▒▓▒▓▓▒░▒▒▒▒▒▓▓▒▒▒▒▒░───────
███▓▓▓█▓▓▓▓▓▒▒▒▒▒▒▒▒▓▓▓▒▒▓▒░▒▓██▓▒▓▓░───────
███▒▓▓▓█▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒▓▓▒▓▓█▓▓▒──────────
███▒▓▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒▓▓▓▓▒▒────────────
████▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒░░░──────────
████▒▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒░░░░░░░░▒─░░────────
████▒▒▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒░░░▒▒░░─░░░░────────
████▓▒▓▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒░░▒▒▒░░░─░░─────────
█████▒▒▓▒▒▓▓▓▓▓▒▒▒▒▓▒▒▒▒░░░░▒▒▒▒░░░─────────
████▓▒▓▓▓▓▓▓▓▓▓▓▓▓▒▓▒▒▒▒▒▒░░▒▒▒▒░░░─────────
████▓▒▓▓▓▓▓▓▒▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒░░─░─────────
████▓▓▓▓▓▓▒▒▒▒▓▓▓▓▓▓▒▒▓▒▒▒▒▒▒▒░─░░░─────────
████▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒░░░░░▒░─────────
"""
"""Grumpy Cat Ascii art."""


def random_phrase():
    """Generate a random phrase.

    Returns
    -------
    str, a random grumpy phrase.
    """
    phrases = [
        "Sometimes you can't tell if you're just in a bad mood\
             or everyone around you is being annoying.",
        "You need a hug for these issues, go hug a cactus.",
        "You have a problem with my attitude? I have an attitude ...\
             you have the problem.",
        "The problem with some people ... is that they exist.",
        "The worst part of my day is hearing you complain about your \
            lint issues."
    ]
    return random.choice(phrases)
